==> schlix-cms-v2.2.2-1.zip: schlix/system/apps/admin/view.deleteinstalldir.template.php <==
<?php
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//
// SCHLIX WEB CONTENT MANAGEMENT SYSTEM - Copyright (C) SCHLIX WEB INC.
// This is a SHARED SOURCE
// You may use this software commercially, but you are not allowed to create a fork or create a derivative of this software
// Please read the license for details
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//
if (!defined('SCHLIX_VERSION'))
    die('No Access');
global $CurrentUser;
?>

<div class=" alert alert-warning">
<form id="schlix_admin_deleteinstalldir" method="POST" action="<?= $this->createFriendlyURL('action=deleteinstalldir') ?>">
    <x-ui:row>
        <x-ui:column sm="6">
            <p><strong><?= ___h(SCHLIX_SITE_NAME) . ' ' . ___('Security Warning') ?></strong></p>
            <?php if ($this->errormsg): ?>
            <p><?= ___h($this->errormsg); ?></p>
    <?php endif; ?>            
        </x-ui:column>
        <!-- column -->
        <x-ui:column sm="3" class="text-right">
        <?php if (is_dir(SCHLIX_ROOT_PATH . '/install')): ?>
        <p><strong><?= ___('Delete Installation Directory?') ?></strong></p>
            <?php elseif ($result): ?>
        <p><?= ___('Installation directory no longer exists or has been renamed or deleted. You\'re good to go!') ?></p>
        <?php endif ?>
        </x-ui:column>
        <?php if (is_dir(SCHLIX_ROOT_PATH . '/install')): ?>
        <x-ui:column sm="3">
            <input type="hidden" name="deleteinstalldir" value="1" />
            <x-ui:button-ok type="submit" fonticon="fa fa-check" label="<?= ___('OK'); ?>" />
        </x-ui:column>
        <?php endif ?>
    </x-ui:row>
    </form>
    
    
    
    
    
    
        
            
            

        
    
</div>

==> schlix-cms-v2.2.7-1.zip: schlix/system/apps/admin/view.deleteinstalldir.template.php <==
<?php
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//
// SCHLIX WEB CONTENT MANAGEMENT SYSTEM - Copyright (C) SCHLIX WEB INC.
// This is a SHARED SOURCE
// You may use this software commercially, but you are not allowed to create a fork or create a derivative of this software
// Please read the license for details
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//
if (!defined('SCHLIX_VERSION'))
    die('No Access');
global $CurrentUser;
?>

<div class=" alert alert-warning">
<form id="schlix_admin_deleteinstalldir" method="POST" action="<?= $this->createFriendlyURL('action=deleteinstalldir') ?>">
    <x-ui:row>
        <x-ui:column sm="6">
            <p><strong><?= ___h(SCHLIX_SITE_NAME) . ' ' . ___('Security Warning') ?></strong></p>
            <?php if ($this->errormsg): ?>
            <p><?= ___h($this->errormsg); ?></p>
    <?php endif; ?>            
        </x-ui:column>
        <!-- column -->
        <x-ui:column sm="3" class="text-right">
        <?php if (is_dir(SCHLIX_ROOT_PATH . '/install')): ?>
        <p><strong><?= ___('Delete Installation Directory?') ?></strong></p>
            <?php elseif ($result): ?>
        <p><?= ___('Installation directory no longer exists or has been renamed or deleted. You\'re good to go!') ?></p>
        <?php endif ?>
        </x-ui:column>
        <?php if (is_dir(SCHLIX_ROOT_PATH . '/install')): ?>
        <x-ui:column sm="3">
            <input type="hidden" name="deleteinstalldir" value="1" />
            <x-ui:button button-type="ok" type="submit" fonticon="fa fa-check" label="<?= ___('OK'); ?>" />
        </x-ui:column>
        <?php endif ?>
    </x-ui:row>
    </form>
    
    
    
    
    
    
        
            
            

        
    
</div>
